{% load static %}
{% load cache %}

<meta charset="utf-8">
<meta content="width=device-width, initial-scale=1.0" name="viewport">

<title>{{ seo.company_name }} | {{ seo.small_title }}</title>
<meta content="" name="{{ seo.desc }}">
<meta content="" name="{{ seo.keywords }}">

<meta property="og:url" content="https://{{ seo.url }}">
<meta property="og:image" itemprop="image primaryImageOfPage" content="{% static 'img/favicon.png' %}">

<meta name="twitter:description" property="og:description" itemprop="description" content="{{ seo.desc }}">
<meta name="twitter:title" property="og:title" itemprop="name" content="{{ seo.company_name }} | {{ seo.small_title }}">

{% cache 86400 base_header %}
<meta property="og:type" content="website">
<meta property="og:site_name" content="{{ seo.url }}">
<meta name="twitter:card" content="summary">
<meta name="twitter:domain" content="{{ seo.url }}">
{% endcache %}

<!-- Favicons -->
<link rel="icon" type="image/png" sizes="32x32" href="{% static 'img/favicon.png' %}">
<link rel="shortcut icon" sizes="16x16 24x24 32x32 48x48" href="{% static 'img/favicon.ico' %}">
<link rel="apple-touch-icon" sizes="180x180" href="{% static 'img/apple-touch-icon.png' %}">

<!-- Google Fonts -->
<link rel="preconnect" href="https://fonts.googleapis.com">
<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
<link href="{{ font_link }}" rel="stylesheet">
