<footer id="footer">
  <div class="container">
    <div class="copyright">
      &copy; Copyright <a href="https://demiansoft.com" target="_blank"><strong><span>Demiansoft</span></strong></a>. All Rights Reserved
    </div>

  </div>
</footer>