/*--------------------------------------------------------------
# Hero Section
--------------------------------------------------------------*/
#hero {
  width: 100%;
  height: 100vh;
  /*background: url("../img/hero-bg.jpg") top center;*/
  background-size: cover;

  &:before {
    content: "";
    background: rgba($secondary, 0.3);
    position: absolute;
    bottom: 0;
    top: 0;
    left: 0;
    right: 0;
    z-index: 1;
  }

  .hero-container {
    position: relative;
    z-index: 2;
    min-width: 300px;
  }


  h1 {
    margin: 0 0 10px 0;
    font-size: 64px;
    font-weight: 700;
    line-height: 56px;
    color: #fff;
  }

  p {
    color: #fff;
    margin-bottom: 50px;
    font-size: 26px;
    font-family: $font-secondary;
    span {
      color: $white;
      padding-bottom: 4px;
      letter-spacing: 1px;
      border-bottom: 3px solid $primary;
    }
  }

  @media (min-width: 1024px) {
    background-attachment: fixed;
  }

  @media (max-width: 768px) {
    h1 {
      font-size: 28px;
      line-height: 36px;
    }
    h2 {
      font-size: 18px;
      line-height: 24px;
      margin-bottom: 30px;
    }
  }

}
