/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/
#footer {
  padding: 15px;
  color: #f4f6fd;
  font-size: 14px;
  position: fixed;
  left: 0;
  bottom: 0;
  width: 300px;
  z-index: 9999;
  background: darken($secondary, 1);

  .copyright {
    text-align: center;
  }

  .credits {
    padding-top: 5px;
    text-align: center;
    font-size: 13px;
    color: #eaebf0;
  }

  @media (max-width: 1199px) {
    position: static;
    width: auto;
    padding-right: 20px 15px;
  }
}

